@@ -8,15 +8,20 @@ play_initials_bank = ['en-GB', 'af', 'am', 'ar', 'hy-AM', 'az-AZ', 'bn-BD', 'eu-
 
 
 # the actual conversion of a text
-def translate_sentence(translate_client, project_id, language_src, language_dest, text):
+def translate_sentence(translate_client,
+                       project_id,
+                       language_src,
+                       language_dest,
+                       text,
+                       html_or_normal_text='normal_text'):
     # translate
     parent = f'projects/{project_id}'
+    text_type = "plain" if html_or_normal_text == 'normal_text' else 'html'
     try:
         response = translate_client.translate_text(
             parent=parent,
             contents=[text],
-            mime_type="text/plain",
-
+            mime_type= f'text/{text_type}',
             source_language_code=language_src,
             target_language_code=language_dest)
 
