@@ -10,7 +10,8 @@ def translate_text(service_account_json_path,
                    project_id,
                    text,
                    language_initials_dest,
-                   language_initials_src='en-US'
+                   language_initials_src='en-US',
+                   html_or_normal_text='normal_text'
                    ):
     """Will translate a text to a given language.
 
@@ -33,4 +34,5 @@ def translate_text(service_account_json_path,
                                  project_id,
                                  language_initials_src,
                                  language_initials_dest,
-                                 text)
+                                 text,
+                                 html_or_normal_text=html_or_normal_text)
